summaryrefslogtreecommitdiff
path: root/connectivity/source/commontools
diff options
context:
space:
mode:
authorNoel Grandin <noel@peralex.com>2016-05-27 12:31:29 +0200
committerNoel Grandin <noelgrandin@gmail.com>2016-05-30 08:37:11 +0000
commita52231c78526e14977d2129fa1abe812de567f03 (patch)
tree8d38fd537ebb43a72b41f4b838bc0effb9d05769 /connectivity/source/commontools
parenta499d1b980be1eb2bd6ccfa07b1d87c02fcb1343 (diff)
com::sun::star->css in connectivity
Change-Id: I9489e92dc89a6d83a26ff4f0d9aad26acd28ad9f Reviewed-on: https://gerrit.libreoffice.org/25537 Tested-by: Jenkins <ci@libreoffice.org> Reviewed-by: Noel Grandin <noelgrandin@gmail.com>
Diffstat (limited to 'connectivity/source/commontools')
-rw-r--r--connectivity/source/commontools/BlobHelper.cxx16
-rw-r--r--connectivity/source/commontools/ConnectionWrapper.cxx14
-rw-r--r--connectivity/source/commontools/DateConversion.cxx26
-rw-r--r--connectivity/source/commontools/FDatabaseMetaDataResultSet.cxx22
-rw-r--r--connectivity/source/commontools/FDatabaseMetaDataResultSetMetaData.cxx2
-rw-r--r--connectivity/source/commontools/FValue.cxx42
-rw-r--r--connectivity/source/commontools/ParamterSubstitution.cxx8
-rw-r--r--connectivity/source/commontools/TConnection.cxx2
-rw-r--r--connectivity/source/commontools/TIndexColumns.cxx2
-rw-r--r--connectivity/source/commontools/TKeyColumns.cxx4
-rw-r--r--connectivity/source/commontools/TTableHelper.cxx38
-rw-r--r--connectivity/source/commontools/conncleanup.cxx14
-rw-r--r--connectivity/source/commontools/dbexception.cxx42
-rw-r--r--connectivity/source/commontools/dbtools.cxx10
-rw-r--r--connectivity/source/commontools/parameters.cxx24
15 files changed, 133 insertions, 133 deletions
diff --git a/connectivity/source/commontools/BlobHelper.cxx b/connectivity/source/commontools/BlobHelper.cxx
index c4e83d759fea..396e3567490f 100644
--- a/connectivity/source/commontools/BlobHelper.cxx
+++ b/connectivity/source/commontools/BlobHelper.cxx
@@ -25,23 +25,23 @@ using namespace dbtools;
using namespace ::com::sun::star::sdbc;
using namespace ::com::sun::star::uno;
-BlobHelper::BlobHelper(const ::com::sun::star::uno::Sequence< sal_Int8 >& _val) : m_aValue(_val)
+BlobHelper::BlobHelper(const css::uno::Sequence< sal_Int8 >& _val) : m_aValue(_val)
{
}
-::sal_Int64 SAL_CALL BlobHelper::length( ) throw (::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
+::sal_Int64 SAL_CALL BlobHelper::length( ) throw (css::sdbc::SQLException, css::uno::RuntimeException, std::exception)
{
return m_aValue.getLength();
}
-::com::sun::star::uno::Sequence< ::sal_Int8 > SAL_CALL BlobHelper::getBytes( ::sal_Int64 pos, ::sal_Int32 _length ) throw (::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< ::sal_Int8 > SAL_CALL BlobHelper::getBytes( ::sal_Int64 pos, ::sal_Int32 _length ) throw (css::sdbc::SQLException, css::uno::RuntimeException, std::exception)
{
if ( sal_Int32(pos + _length) > m_aValue.getLength() )
- throw ::com::sun::star::sdbc::SQLException();
- return ::com::sun::star::uno::Sequence< ::sal_Int8 >(m_aValue.getConstArray() + sal_Int32(pos),_length);
+ throw css::sdbc::SQLException();
+ return css::uno::Sequence< ::sal_Int8 >(m_aValue.getConstArray() + sal_Int32(pos),_length);
}
-::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream > SAL_CALL BlobHelper::getBinaryStream( ) throw (::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Reference< css::io::XInputStream > SAL_CALL BlobHelper::getBinaryStream( ) throw (css::sdbc::SQLException, css::uno::RuntimeException, std::exception)
{
return new ::comphelper::SequenceInputStream(m_aValue);
}
@@ -53,13 +53,13 @@ BlobHelper::BlobHelper(const ::com::sun::star::uno::Sequence< sal_Int8 >& _val)
SAL_WNOUNREACHABLE_CODE_PUSH
-::sal_Int64 SAL_CALL BlobHelper::position( const ::com::sun::star::uno::Sequence< ::sal_Int8 >& /*pattern*/, ::sal_Int64 /*start*/ ) throw (::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
+::sal_Int64 SAL_CALL BlobHelper::position( const css::uno::Sequence< ::sal_Int8 >& /*pattern*/, ::sal_Int64 /*start*/ ) throw (css::sdbc::SQLException, css::uno::RuntimeException, std::exception)
{
::dbtools::throwFeatureNotImplementedSQLException( "XBlob::position", *this );
return 0;
}
-::sal_Int64 SAL_CALL BlobHelper::positionOfBlob( const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XBlob >& /*pattern*/, ::sal_Int64 /*start*/ ) throw (::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
+::sal_Int64 SAL_CALL BlobHelper::positionOfBlob( const css::uno::Reference< css::sdbc::XBlob >& /*pattern*/, ::sal_Int64 /*start*/ ) throw (css::sdbc::SQLException, css::uno::RuntimeException, std::exception)
{
::dbtools::throwFeatureNotImplementedSQLException( "XBlob::positionOfBlob", *this );
return 0;
diff --git a/connectivity/source/commontools/ConnectionWrapper.cxx b/connectivity/source/commontools/ConnectionWrapper.cxx
index aa60abf8c3e2..f28c0e8ab538 100644
--- a/connectivity/source/commontools/ConnectionWrapper.cxx
+++ b/connectivity/source/commontools/ConnectionWrapper.cxx
@@ -105,13 +105,13 @@ OConnectionWrapper::~OConnectionWrapper()
// XServiceInfo
-OUString SAL_CALL OConnectionWrapper::getImplementationName( ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+OUString SAL_CALL OConnectionWrapper::getImplementationName( ) throw (css::uno::RuntimeException, std::exception)
{
return OUString( "com.sun.star.sdbc.drivers.OConnectionWrapper" );
}
-::com::sun::star::uno::Sequence< OUString > SAL_CALL OConnectionWrapper::getSupportedServiceNames( ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+css::uno::Sequence< OUString > SAL_CALL OConnectionWrapper::getSupportedServiceNames( ) throw(css::uno::RuntimeException, std::exception)
{
// first collect the services which are supported by our aggregate
Sequence< OUString > aSupported;
@@ -132,7 +132,7 @@ OUString SAL_CALL OConnectionWrapper::getImplementationName( ) throw (::com::su
}
-sal_Bool SAL_CALL OConnectionWrapper::supportsService( const OUString& _rServiceName ) throw(::com::sun::star::uno::RuntimeException, std::exception)
+sal_Bool SAL_CALL OConnectionWrapper::supportsService( const OUString& _rServiceName ) throw(css::uno::RuntimeException, std::exception)
{
return cppu::supportsService(this, _rServiceName);
}
@@ -144,7 +144,7 @@ Any SAL_CALL OConnectionWrapper::queryInterface( const Type& _rType ) throw (Run
return aReturn.hasValue() ? aReturn : (m_xProxyConnection.is() ? m_xProxyConnection->queryAggregation(_rType) : aReturn);
}
-Sequence< Type > SAL_CALL OConnectionWrapper::getTypes( ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+Sequence< Type > SAL_CALL OConnectionWrapper::getTypes( ) throw (css::uno::RuntimeException, std::exception)
{
return ::comphelper::concatSequences(
OConnection_BASE::getTypes(),
@@ -152,7 +152,7 @@ Sequence< Type > SAL_CALL OConnectionWrapper::getTypes( ) throw (::com::sun::st
);
}
-// com::sun::star::lang::XUnoTunnel
+// css::lang::XUnoTunnel
sal_Int64 SAL_CALL OConnectionWrapper::getSomething( const Sequence< sal_Int8 >& rId ) throw(RuntimeException, std::exception)
{
if (rId.getLength() == 16 && 0 == memcmp(getUnoTunnelImplementationId().getConstArray(), rId.getConstArray(), 16 ) )
@@ -181,12 +181,12 @@ Sequence< sal_Int8 > OConnectionWrapper::getUnoTunnelImplementationId()
namespace
{
- class TPropertyValueLessFunctor : public ::std::binary_function< ::com::sun::star::beans::PropertyValue,::com::sun::star::beans::PropertyValue,bool>
+ class TPropertyValueLessFunctor : public ::std::binary_function< css::beans::PropertyValue,css::beans::PropertyValue,bool>
{
public:
TPropertyValueLessFunctor()
{}
- bool operator() (const ::com::sun::star::beans::PropertyValue& lhs, const ::com::sun::star::beans::PropertyValue& rhs) const
+ bool operator() (const css::beans::PropertyValue& lhs, const css::beans::PropertyValue& rhs) const
{
return lhs.Name.compareToIgnoreAsciiCase(rhs.Name) < 0;
}
diff --git a/connectivity/source/commontools/DateConversion.cxx b/connectivity/source/commontools/DateConversion.cxx
index 4fa406653e4a..1986adc5e08e 100644
--- a/connectivity/source/commontools/DateConversion.cxx
+++ b/connectivity/source/commontools/DateConversion.cxx
@@ -59,7 +59,7 @@ OUString DBTypeConversion::toSQLString(sal_Int32 eType, const Any& _rVal, bool b
case DataType::BOOLEAN:
case DataType::TINYINT:
case DataType::SMALLINT:
- if (_rVal.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_BOOLEAN)
+ if (_rVal.getValueType().getTypeClass() == css::uno::TypeClass_BOOLEAN)
{
if (::cppu::any2bool(_rVal))
aRet.append("1");
@@ -112,14 +112,14 @@ OUString DBTypeConversion::toSQLString(sal_Int32 eType, const Any& _rVal, bool b
{
DateTime aDateTime;
bool bOk = false;
- if (_rVal.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_DOUBLE)
+ if (_rVal.getValueType().getTypeClass() == css::uno::TypeClass_DOUBLE)
{
double nValue = 0.0;
_rVal >>= nValue;
aDateTime = DBTypeConversion::toDateTime(nValue);
bOk = true;
}
- else if (_rVal.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_STRING)
+ else if (_rVal.getValueType().getTypeClass() == css::uno::TypeClass_STRING)
{
OUString sValue;
_rVal >>= sValue;
@@ -146,14 +146,14 @@ OUString DBTypeConversion::toSQLString(sal_Int32 eType, const Any& _rVal, bool b
{
Date aDate;
bool bOk = false;
- if (_rVal.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_DOUBLE)
+ if (_rVal.getValueType().getTypeClass() == css::uno::TypeClass_DOUBLE)
{
double nValue = 0.0;
_rVal >>= nValue;
aDate = DBTypeConversion::toDate(nValue);
bOk = true;
}
- else if (_rVal.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_STRING)
+ else if (_rVal.getValueType().getTypeClass() == css::uno::TypeClass_STRING)
{
OUString sValue;
_rVal >>= sValue;
@@ -173,14 +173,14 @@ OUString DBTypeConversion::toSQLString(sal_Int32 eType, const Any& _rVal, bool b
{
css::util::Time aTime;
bool bOk = false;
- if (_rVal.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_DOUBLE)
+ if (_rVal.getValueType().getTypeClass() == css::uno::TypeClass_DOUBLE)
{
double nValue = 0.0;
_rVal >>= nValue;
aTime = DBTypeConversion::toTime(nValue);
bOk = true;
}
- else if (_rVal.getValueType().getTypeClass() == ::com::sun::star::uno::TypeClass_STRING)
+ else if (_rVal.getValueType().getTypeClass() == css::uno::TypeClass_STRING)
{
OUString sValue;
_rVal >>= sValue;
@@ -234,7 +234,7 @@ void DBTypeConversion::setValue(const Reference<XColumnUpdate>& xVariant,
const OUString& rString,
sal_Int32 nKey,
sal_Int16 nFieldType,
- sal_Int16 nKeyType) throw(::com::sun::star::lang::IllegalArgumentException)
+ sal_Int16 nKeyType) throw(css::lang::IllegalArgumentException)
{
if (!rString.isEmpty())
{
@@ -317,9 +317,9 @@ void DBTypeConversion::setValue(const Reference<XColumnUpdate>& xVariant,
{
switch (nFieldType)
{
- case ::com::sun::star::sdbc::DataType::CHAR:
- case ::com::sun::star::sdbc::DataType::VARCHAR:
- case ::com::sun::star::sdbc::DataType::LONGVARCHAR:
+ case css::sdbc::DataType::CHAR:
+ case css::sdbc::DataType::VARCHAR:
+ case css::sdbc::DataType::LONGVARCHAR:
xVariant->updateString(rString);
break;
default:
@@ -332,7 +332,7 @@ void DBTypeConversion::setValue(const Reference<XColumnUpdate>& xVariant,
void DBTypeConversion::setValue(const Reference<XColumnUpdate>& xVariant,
const Date& rNullDate,
const double& rValue,
- sal_Int16 nKeyType) throw(::com::sun::star::lang::IllegalArgumentException)
+ sal_Int16 nKeyType) throw(css::lang::IllegalArgumentException)
{
switch (nKeyType & ~NumberFormat::DEFINED)
{
@@ -424,7 +424,7 @@ double DBTypeConversion::getValue( const Reference< XColumn >& i_column, const D
OUString DBTypeConversion::getFormattedValue(const Reference< XPropertySet>& _xColumn,
const Reference<XNumberFormatter>& _xFormatter,
- const ::com::sun::star::lang::Locale& _rLocale,
+ const css::lang::Locale& _rLocale,
const Date& _rNullDate)
{
OSL_ENSURE(_xColumn.is() && _xFormatter.is(), "DBTypeConversion::getFormattedValue: invalid arg !");
diff --git a/connectivity/source/commontools/FDatabaseMetaDataResultSet.cxx b/connectivity/source/commontools/FDatabaseMetaDataResultSet.cxx
index d78dad6ebd9c..3337bd12ad79 100644
--- a/connectivity/source/commontools/FDatabaseMetaDataResultSet.cxx
+++ b/connectivity/source/commontools/FDatabaseMetaDataResultSet.cxx
@@ -149,9 +149,9 @@ Any SAL_CALL ODatabaseMetaDataResultSet::queryInterface( const Type & rType ) th
Sequence< Type > SAL_CALL ODatabaseMetaDataResultSet::getTypes( ) throw(RuntimeException, std::exception)
{
- ::cppu::OTypeCollection aTypes( cppu::UnoType<com::sun::star::beans::XMultiPropertySet>::get(),
- cppu::UnoType<com::sun::star::beans::XFastPropertySet>::get(),
- cppu::UnoType<com::sun::star::beans::XPropertySet>::get());
+ ::cppu::OTypeCollection aTypes( cppu::UnoType<css::beans::XMultiPropertySet>::get(),
+ cppu::UnoType<css::beans::XFastPropertySet>::get(),
+ cppu::UnoType<css::beans::XPropertySet>::get());
return ::comphelper::concatSequences(aTypes.getTypes(),ODatabaseMetaDataResultSet_BASE::getTypes());
}
@@ -187,18 +187,18 @@ sal_Int32 SAL_CALL ODatabaseMetaDataResultSet::findColumn( const OUString& colum
#endif
}
-void ODatabaseMetaDataResultSet::checkIndex(sal_Int32 columnIndex ) throw(::com::sun::star::sdbc::SQLException)
+void ODatabaseMetaDataResultSet::checkIndex(sal_Int32 columnIndex ) throw(css::sdbc::SQLException)
{
if(columnIndex >= (sal_Int32)(*m_aRowsIter).size() || columnIndex < 1)
::dbtools::throwInvalidIndexException(*this);
}
-Reference< ::com::sun::star::io::XInputStream > SAL_CALL ODatabaseMetaDataResultSet::getBinaryStream( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException, std::exception)
+Reference< css::io::XInputStream > SAL_CALL ODatabaseMetaDataResultSet::getBinaryStream( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException, std::exception)
{
return nullptr;
}
-Reference< ::com::sun::star::io::XInputStream > SAL_CALL ODatabaseMetaDataResultSet::getCharacterStream( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException, std::exception)
+Reference< css::io::XInputStream > SAL_CALL ODatabaseMetaDataResultSet::getCharacterStream( sal_Int32 /*columnIndex*/ ) throw(SQLException, RuntimeException, std::exception)
{
return nullptr;
}
@@ -222,7 +222,7 @@ Sequence< sal_Int8 > SAL_CALL ODatabaseMetaDataResultSet::getBytes( sal_Int32 co
}
-::com::sun::star::util::Date SAL_CALL ODatabaseMetaDataResultSet::getDate( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+css::util::Date SAL_CALL ODatabaseMetaDataResultSet::getDate( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
{
return getValue(columnIndex);
}
@@ -293,7 +293,7 @@ Reference< XRef > SAL_CALL ODatabaseMetaDataResultSet::getRef( sal_Int32 /*colum
}
-Any SAL_CALL ODatabaseMetaDataResultSet::getObject( sal_Int32 columnIndex, const Reference< ::com::sun::star::container::XNameAccess >& /*typeMap*/ ) throw(SQLException, RuntimeException, std::exception)
+Any SAL_CALL ODatabaseMetaDataResultSet::getObject( sal_Int32 columnIndex, const Reference< css::container::XNameAccess >& /*typeMap*/ ) throw(SQLException, RuntimeException, std::exception)
{
return getValue(columnIndex).makeAny();
}
@@ -311,13 +311,13 @@ OUString SAL_CALL ODatabaseMetaDataResultSet::getString( sal_Int32 columnIndex )
}
-::com::sun::star::util::Time SAL_CALL ODatabaseMetaDataResultSet::getTime( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+css::util::Time SAL_CALL ODatabaseMetaDataResultSet::getTime( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
{
return getValue(columnIndex);
}
-::com::sun::star::util::DateTime SAL_CALL ODatabaseMetaDataResultSet::getTimestamp( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
+css::util::DateTime SAL_CALL ODatabaseMetaDataResultSet::getTimestamp( sal_Int32 columnIndex ) throw(SQLException, RuntimeException, std::exception)
{
return getValue(columnIndex);
}
@@ -638,7 +638,7 @@ void ODatabaseMetaDataResultSet::setImportedKeysMap()
m_xMetaData = pMetaData;
}
-Reference< ::com::sun::star::beans::XPropertySetInfo > SAL_CALL ODatabaseMetaDataResultSet::getPropertySetInfo( ) throw(RuntimeException, std::exception)
+Reference< css::beans::XPropertySetInfo > SAL_CALL ODatabaseMetaDataResultSet::getPropertySetInfo( ) throw(RuntimeException, std::exception)
{
return ::cppu::OPropertySetHelper::createPropertySetInfo(getInfoHelper());
}
diff --git a/connectivity/source/commontools/FDatabaseMetaDataResultSetMetaData.cxx b/connectivity/source/commontools/FDatabaseMetaDataResultSetMetaData.cxx
index d75b8e5b4f94..99479ca760f0 100644
--- a/connectivity/source/commontools/FDatabaseMetaDataResultSetMetaData.cxx
+++ b/connectivity/source/commontools/FDatabaseMetaDataResultSetMetaData.cxx
@@ -134,7 +134,7 @@ sal_Int32 SAL_CALL ODatabaseMetaDataResultSetMetaData::getPrecision( sal_Int32 c
return 0;
}
-sal_Int32 SAL_CALL ODatabaseMetaDataResultSetMetaData::getScale( sal_Int32 column ) throw(::com::sun::star::sdbc::SQLException, ::com::sun::star::uno::RuntimeException, std::exception)
+sal_Int32 SAL_CALL ODatabaseMetaDataResultSetMetaData::getScale( sal_Int32 column ) throw(css::sdbc::SQLException, css::uno::RuntimeException, std::exception)
{
if(m_mColumns.size() && (m_mColumnsIter = m_mColumns.find(column)) != m_mColumns.end())
return (*m_mColumnsIter).second.getScale();
diff --git a/connectivity/source/commontools/ParamterSubstitution.cxx b/connectivity/source/commontools/ParamterSubstitution.cxx
index 95a8ebb5bdac..59d24110c09b 100644
--- a/connectivity/source/commontools/ParamterSubstitution.cxx
+++ b/connectivity/source/commontools/ParamterSubstitution.cxx
@@ -28,7 +28,7 @@ namespace connectivity
using namespace ::com::sun::star::lang;
using namespace ::com::sun::star;
- ParameterSubstitution::ParameterSubstitution(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XComponentContext >& _rxContext ) : m_xContext(_rxContext)
+ ParameterSubstitution::ParameterSubstitution(const css::uno::Reference< css::uno::XComponentContext >& _rxContext ) : m_xContext(_rxContext)
{
}
void SAL_CALL ParameterSubstitution::initialize( const uno::Sequence< uno::Any >& _aArguments ) throw (uno::Exception, uno::RuntimeException, std::exception)
@@ -72,7 +72,7 @@ namespace connectivity
return *(new ParameterSubstitution(_xContext));
}
- OUString SAL_CALL ParameterSubstitution::substituteVariables( const OUString& _sText, sal_Bool /*bSubstRequired*/ ) throw (::com::sun::star::container::NoSuchElementException, ::com::sun::star::uno::RuntimeException, std::exception)
+ OUString SAL_CALL ParameterSubstitution::substituteVariables( const OUString& _sText, sal_Bool /*bSubstRequired*/ ) throw (css::container::NoSuchElementException, css::uno::RuntimeException, std::exception)
{
OUString sRet = _sText;
uno::Reference< sdbc::XConnection > xConnection = m_xConnection;
@@ -99,12 +99,12 @@ namespace connectivity
return sRet;
}
- OUString SAL_CALL ParameterSubstitution::reSubstituteVariables( const OUString& _sText ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ OUString SAL_CALL ParameterSubstitution::reSubstituteVariables( const OUString& _sText ) throw (css::uno::RuntimeException, std::exception)
{
return _sText;
}
- OUString SAL_CALL ParameterSubstitution::getSubstituteVariableValue( const OUString& /*variable*/ ) throw (::com::sun::star::container::NoSuchElementException, ::com::sun::star::uno::RuntimeException, std::exception)
+ OUString SAL_CALL ParameterSubstitution::getSubstituteVariableValue( const OUString& /*variable*/ ) throw (css::container::NoSuchElementException, css::uno::RuntimeException, std::exception)
{
throw container::NoSuchElementException();
}
diff --git a/connectivity/source/commontools/TConnection.cxx b/connectivity/source/commontools/TConnection.cxx
index e613468454b7..7e34c98116d0 100644
--- a/connectivity/source/commontools/TConnection.cxx
+++ b/connectivity/source/commontools/TConnection.cxx
@@ -56,7 +56,7 @@ void OMetaConnection::disposing()
m_aStatements.clear();
}
//XUnoTunnel
-sal_Int64 SAL_CALL OMetaConnection::getSomething( const ::com::sun::star::uno::Sequence< sal_Int8 >& rId ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+sal_Int64 SAL_CALL OMetaConnection::getSomething( const css::uno::Sequence< sal_Int8 >& rId ) throw (css::uno::RuntimeException, std::exception)
{
return (rId.getLength() == 16 && 0 == memcmp(getUnoTunnelImplementationId().getConstArray(), rId.getConstArray(), 16 ) )
? reinterpret_cast< sal_Int64 >( this )
diff --git a/connectivity/source/commontools/TIndexColumns.cxx b/connectivity/source/commontools/TIndexColumns.cxx
index fe4a9cda3632..c5b9249fb544 100644
--- a/connectivity/source/commontools/TIndexColumns.cxx
+++ b/connectivity/source/commontools/TIndexColumns.cxx
@@ -48,7 +48,7 @@ sdbcx::ObjectType OIndexColumns::createObject(const OUString& _rName)
{
::dbtools::OPropertyMap& rPropMap = OMetaConnection::getPropMap();
OUString aCatalog, aSchema, aTable;
- ::com::sun::star::uno::Any Catalog(m_pIndex->getTable()->getPropertyValue(rPropMap.getNameByIndex(PROPERTY_ID_CATALOGNAME)));
+ css::uno::Any Catalog(m_pIndex->getTable()->getPropertyValue(rPropMap.getNameByIndex(PROPERTY_ID_CATALOGNAME)));
Catalog >>= aCatalog;
m_pIndex->getTable()->getPropertyValue(rPropMap.getNameByIndex(PROPERTY_ID_SCHEMANAME)) >>= aSchema;
m_pIndex->getTable()->getPropertyValue(rPropMap.getNameByIndex(PROPERTY_ID_NAME)) >>= aTable;
diff --git a/connectivity/source/commontools/TKeyColumns.cxx b/connectivity/source/commontools/TKeyColumns.cxx
index 278ff6a03c26..b2ad1966a435 100644
--- a/connectivity/source/commontools/TKeyColumns.cxx
+++ b/connectivity/source/commontools/TKeyColumns.cxx
@@ -49,7 +49,7 @@ sdbcx::ObjectType OKeyColumnsHelper::createObject(const OUString& _rName)
{
::dbtools::OPropertyMap& rPropMap = OMetaConnection::getPropMap();
OUString aCatalog, aSchema, aTable;
- ::com::sun::star::uno::Any Catalog(m_pKey->getTable()->getPropertyValue(rPropMap.getNameByIndex(PROPERTY_ID_CATALOGNAME)));
+ css::uno::Any Catalog(m_pKey->getTable()->getPropertyValue(rPropMap.getNameByIndex(PROPERTY_ID_CATALOGNAME)));
Catalog >>= aCatalog;
m_pKey->getTable()->getPropertyValue(rPropMap.getNameByIndex(PROPERTY_ID_SCHEMANAME)) >>= aSchema;
m_pKey->getTable()->getPropertyValue(rPropMap.getNameByIndex(PROPERTY_ID_NAME)) >>= aTable;
@@ -129,7 +129,7 @@ Reference< XPropertySet > OKeyColumnsHelper::createDescriptor()
return new OKeyColumn(isCaseSensitive());
}
-void OKeyColumnsHelper::impl_refresh() throw(::com::sun::star::uno::RuntimeException)
+void OKeyColumnsHelper::impl_refresh() throw(css::uno::RuntimeException)
{
m_pKey->refreshColumns();
}
diff --git a/connectivity/source/commontools/TTableHelper.cxx b/connectivity/source/commontools/TTableHelper.cxx
index eefd94eee961..5db35247f267 100644
--- a/connectivity/source/commontools/TTableHelper.cxx
+++ b/connectivity/source/commontools/TTableHelper.cxx
@@ -66,17 +66,17 @@ public:
// noncopyable
OTableContainerListener(const OTableContainerListener&) = delete;
const OTableContainerListener& operator=(const OTableContainerListener&) = delete;
- virtual void SAL_CALL elementInserted( const ::com::sun::star::container::ContainerEvent& /*Event*/ ) throw (RuntimeException, std::exception) override
+ virtual void SAL_CALL elementInserted( const css::container::ContainerEvent& /*Event*/ ) throw (RuntimeException, std::exception) override
{
}
- virtual void SAL_CALL elementRemoved( const ::com::sun::star::container::ContainerEvent& Event ) throw (RuntimeException, std::exception) override
+ virtual void SAL_CALL elementRemoved( const css::container::ContainerEvent& Event ) throw (RuntimeException, std::exception) override
{
OUString sName;
Event.Accessor >>= sName;
if ( m_aRefNames.find(sName) != m_aRefNames.end() )
m_pComponent->refreshKeys();
}
- virtual void SAL_CALL elementReplaced( const ::com::sun::star::container::ContainerEvent& Event ) throw (RuntimeException, std::exception) override
+ virtual void SAL_CALL elementReplaced( const css::container::ContainerEvent& Event ) throw (RuntimeException, std::exception) override
{
OUString sOldComposedName,sNewComposedName;
Event.ReplacedElement >>= sOldComposedName;
@@ -94,7 +94,7 @@ public:
}
namespace connectivity
{
- OUString lcl_getServiceNameForSetting(const Reference< ::com::sun::star::sdbc::XConnection >& _xConnection,const OUString& i_sSetting)
+ OUString lcl_getServiceNameForSetting(const Reference< css::sdbc::XConnection >& _xConnection,const OUString& i_sSetting)
{
OUString sSupportService;
Any aValue;
@@ -108,16 +108,16 @@ namespace connectivity
{
TKeyMap m_aKeys;
// helper services which can be provided by extensions
- Reference< ::com::sun::star::sdb::tools::XTableRename> m_xRename;
- Reference< ::com::sun::star::sdb::tools::XTableAlteration> m_xAlter;
- Reference< ::com::sun::star::sdb::tools::XKeyAlteration> m_xKeyAlter;
- Reference< ::com::sun::star::sdb::tools::XIndexAlteration> m_xIndexAlter;
-
- Reference< ::com::sun::star::sdbc::XDatabaseMetaData > m_xMetaData;
- Reference< ::com::sun::star::sdbc::XConnection > m_xConnection;
- rtl::Reference<OTableContainerListener> m_xTablePropertyListener;
- ::std::vector< ColumnDesc > m_aColumnDesc;
- explicit OTableHelperImpl(const Reference< ::com::sun::star::sdbc::XConnection >& _xConnection)
+ Reference< css::sdb::tools::XTableRename> m_xRename;
+ Reference< css::sdb::tools::XTableAlteration> m_xAlter;
+ Reference< css::sdb::tools::XKeyAlteration> m_xKeyAlter;
+ Reference< css::sdb::tools::XIndexAlteration> m_xIndexAlter;
+
+ Reference< css::sdbc::XDatabaseMetaData > m_xMetaData;
+ Reference< css::sdbc::XConnection > m_xConnection;
+ rtl::Reference<OTableContainerListener> m_xTablePropertyListener;
+ ::std::vector< ColumnDesc > m_aColumnDesc;
+ explicit OTableHelperImpl(const Reference< css::sdbc::XConnection >& _xConnection)
: m_xConnection(_xConnection)
{
try
@@ -542,7 +542,7 @@ Reference< XDatabaseMetaData> OTableHelper::getMetaData() const
return m_pImpl->m_xMetaData;
}
-void SAL_CALL OTableHelper::alterColumnByIndex( sal_Int32 index, const Reference< XPropertySet >& descriptor ) throw(SQLException, ::com::sun::star::lang::IndexOutOfBoundsException, RuntimeException, std::exception)
+void SAL_CALL OTableHelper::alterColumnByIndex( sal_Int32 index, const Reference< XPropertySet >& descriptor ) throw(SQLException, css::lang::IndexOutOfBoundsException, RuntimeException, std::exception)
{
::osl::MutexGuard aGuard(m_aMutex);
checkDisposed(
@@ -609,22 +609,22 @@ Reference< XConnection> OTableHelper::getConnection() const
return m_pImpl->m_xConnection;
}
-Reference< ::com::sun::star::sdb::tools::XTableRename> OTableHelper::getRenameService() const
+Reference< css::sdb::tools::XTableRename> OTableHelper::getRenameService() const
{
return m_pImpl->m_xRename;
}
-Reference< ::com::sun::star::sdb::tools::XTableAlteration> OTableHelper::getAlterService() const
+Reference< css::sdb::tools::XTableAlteration> OTableHelper::getAlterService() const
{
return m_pImpl->m_xAlter;
}
-Reference< ::com::sun::star::sdb::tools::XKeyAlteration> OTableHelper::getKeyService() const
+Reference< css::sdb::tools::XKeyAlteration> OTableHelper::getKeyService() const
{
return m_pImpl->m_xKeyAlter;
}
-Reference< ::com::sun::star::sdb::tools::XIndexAlteration> OTableHelper::getIndexService() const
+Reference< css::sdb::tools::XIndexAlteration> OTableHelper::getIndexService() const
{
return m_pImpl->m_xIndexAlter;
}
diff --git a/connectivity/source/commontools/conncleanup.cxx b/connectivity/source/commontools/conncleanup.cxx
index c140474fbcd1..9b5f780e8a66 100644
--- a/connectivity/source/commontools/conncleanup.cxx
+++ b/connectivity/source/commontools/conncleanup.cxx
@@ -27,10 +27,10 @@ namespace dbtools
{
- using namespace ::com::sun::star::uno;
- using namespace ::com::sun::star::beans;
- using namespace ::com::sun::star::sdbc;
- using namespace ::com::sun::star::lang;
+ using namespace css::uno;
+ using namespace css::beans;
+ using namespace css::sdbc;
+ using namespace css::lang;
static const char ACTIVE_CONNECTION_PROPERTY_NAME[] = "ActiveConnection";
@@ -204,15 +204,15 @@ namespace dbtools
}
}
- void SAL_CALL OAutoConnectionDisposer::cursorMoved( const ::com::sun::star::lang::EventObject& /*event*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ void SAL_CALL OAutoConnectionDisposer::cursorMoved( const css::lang::EventObject& /*event*/ ) throw (css::uno::RuntimeException, std::exception)
{
}
- void SAL_CALL OAutoConnectionDisposer::rowChanged( const ::com::sun::star::lang::EventObject& /*event*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ void SAL_CALL OAutoConnectionDisposer::rowChanged( const css::lang::EventObject& /*event*/ ) throw (css::uno::RuntimeException, std::exception)
{
}
- void SAL_CALL OAutoConnectionDisposer::rowSetChanged( const ::com::sun::star::lang::EventObject& /*event*/ ) throw (::com::sun::star::uno::RuntimeException, std::exception)
+ void SAL_CALL OAutoConnectionDisposer::rowSetChanged( const css::lang::EventObject& /*event*/ ) throw (css::uno::RuntimeException, std::exception)
{
stopRowSetListening();
clearConnection();
diff --git a/connectivity/source/commontools/dbexception.cxx b/connectivity/source/commontools/dbexception.cxx
index 8cb71fb0ed3d..f718a3ceb218 100644
--- a/connectivity/source/commontools/dbexception.cxx
+++ b/connectivity/source/commontools/dbexception.cxx
@@ -45,21 +45,21 @@ SQLExceptionInfo::SQLExceptionInfo()
}
-SQLExceptionInfo::SQLExceptionInfo(const ::com::sun::star::sdbc::SQLException& _rError)
+SQLExceptionInfo::SQLExceptionInfo(const css::sdbc::SQLException& _rError)
{
m_aContent <<= _rError;
implDetermineType();
}
-SQLExceptionInfo::SQLExceptionInfo(const ::com::sun::star::sdbc::SQLWarning& _rError)
+SQLExceptionInfo::SQLExceptionInfo(const css::sdbc::SQLWarning& _rError)
{
m_aContent <<= _rError;
implDetermineType();
}
-SQLExceptionInfo::SQLExceptionInfo(const ::com::sun::star::sdb::SQLContext& _rError)
+SQLExceptionInfo::SQLExceptionInfo(const css::sdb::SQLContext& _rError)
{
m_aContent <<= _rError;
implDetermineType();
@@ -82,7 +82,7 @@ SQLExceptionInfo::SQLExceptionInfo(const SQLExceptionInfo& _rCopySource)
}
-SQLExceptionInfo& SQLExceptionInfo::operator=(const ::com::sun::star::sdbc::SQLException& _rError)
+SQLExceptionInfo& SQLExceptionInfo::operator=(const css::sdbc::SQLException& _rError)
{
m_aContent <<= _rError;
implDetermineType();
@@ -90,7 +90,7 @@ SQLExceptionInfo& SQLExceptionInfo::operator=(const ::com::sun::star::sdbc::SQLE
}
-SQLExceptionInfo& SQLExceptionInfo::operator=(const ::com::sun::star::sdbc::SQLWarning& _rError)
+SQLExceptionInfo& SQLExceptionInfo::operator=(const css::sdbc::SQLWarning& _rError)
{
m_aContent <<= _rError;
implDetermineType();
@@ -98,7 +98,7 @@ SQLExceptionInfo& SQLExceptionInfo::operator=(const ::com::sun::star::sdbc::SQLW
}
-SQLExceptionInfo& SQLExceptionInfo::operator=(const ::com::sun::star::sdb::SQLContext& _rError)
+SQLExceptionInfo& SQLExceptionInfo::operator=(const css::sdb::SQLContext& _rError)
{
m_aContent <<= _rError;
implDetermineType();
@@ -106,7 +106,7 @@ SQLExceptionInfo& SQLExceptionInfo::operator=(const ::com::sun::star::sdb::SQLCo
}
-SQLExceptionInfo& SQLExceptionInfo::operator=(const ::com::sun::star::sdb::SQLErrorEvent& _rErrorEvent)
+SQLExceptionInfo& SQLExceptionInfo::operator=(const css::sdb::SQLErrorEvent& _rErrorEvent)
{
m_aContent = _rErrorEvent.Reason;
implDetermineType();
@@ -114,7 +114,7 @@ SQLExceptionInfo& SQLExceptionInfo::operator=(const ::com::sun::star::sdb::SQLEr
}
-SQLExceptionInfo& SQLExceptionInfo::operator=(const ::com::sun::star::uno::Any& _rCaughtSQLException)
+SQLExceptionInfo& SQLExceptionInfo::operator=(const css::uno::Any& _rCaughtSQLException)
{
m_aContent = _rCaughtSQLException;
implDetermineType();
@@ -124,7 +124,7 @@ SQLExceptionInfo& SQLExceptionInfo::operator=(const ::com::sun::star::uno::Any&
SQLExceptionInfo::SQLExceptionInfo(const css::uno::Any& _rError)
{
- const css::uno::Type& aSQLExceptionType = cppu::UnoType<com::sun::star::sdbc::SQLException>::get();
+ const css::uno::Type& aSQLExceptionType = cppu::UnoType<css::sdbc::SQLException>::get();
bool bValid = isAssignableFrom(aSQLExceptionType, _rError.getValueType());
if (bValid)
m_aContent = _rError;
@@ -171,17 +171,17 @@ bool SQLExceptionInfo::isKindOf(TYPE _eType) const
}
-SQLExceptionInfo::operator const ::com::sun::star::sdbc::SQLException*() const
+SQLExceptionInfo::operator const css::sdbc::SQLException*() const
{
OSL_ENSURE(isKindOf(TYPE::SQLException), "SQLExceptionInfo::operator SQLException* : invalid call !");
- return static_cast<const ::com::sun::star::sdbc::SQLException*>(m_aContent.getValue());
+ return static_cast<const css::sdbc::SQLException*>(m_aContent.getValue());
}
-SQLExceptionInfo::operator const ::com::sun::star::sdb::SQLContext*() const
+SQLExceptionInfo::operator const css::sdb::SQLContext*() const
{
OSL_ENSURE(isKindOf(TYPE::SQLContext), "SQLExceptionInfo::operator SQLException* : invalid call !");
- return static_cast<const ::com::sun::star::sdb::SQLContext*>(m_aContent.getValue());
+ return static_cast<const css::sdb::SQLContext*>(m_aContent.getValue());
}
@@ -263,7 +263,7 @@ SQLExceptionIteratorHelper::SQLExceptionIteratorHelper( const SQLExceptionInfo&
}
-SQLExceptionIteratorHelper::SQLExceptionIteratorHelper( const ::com::sun::star::sdbc::SQLException& _rChainStart )
+SQLExceptionIteratorHelper::SQLExceptionIteratorHelper( const css::sdbc::SQLException& _rChainStart )
:m_pCurrent( &_rChainStart )
,m_eCurrentType( SQLExceptionInfo::TYPE::SQLException )
{
@@ -293,11 +293,11 @@ void SQLExceptionIteratorHelper::current( SQLExceptionInfo& _out_rInfo ) const
}
-const ::com::sun::star::sdbc::SQLException* SQLExceptionIteratorHelper::next()
+const css::sdbc::SQLException* SQLExceptionIteratorHelper::next()
{
OSL_ENSURE( hasMoreElements(), "SQLExceptionIteratorHelper::next : invalid call (please use hasMoreElements)!" );
- const ::com::sun::star::sdbc::SQLException* pReturn = current();
+ const css::sdbc::SQLException* pReturn = current();
if ( !m_pCurrent )
return pReturn;
@@ -343,7 +343,7 @@ void SQLExceptionIteratorHelper::next( SQLExceptionInfo& _out_rInfo )
}
-void throwFunctionSequenceException(const Reference< XInterface >& Context, const Any& Next) throw ( ::com::sun::star::sdbc::SQLException )
+void throwFunctionSequenceException(const Reference< XInterface >& Context, const Any& Next) throw ( css::sdbc::SQLException )
{
::connectivity::SharedResources aResources;
throw SQLException(
@@ -355,8 +355,8 @@ void throwFunctionSequenceException(const Reference< XInterface >& Context, cons
);
}
-void throwInvalidIndexException(const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& Context,
- const ::com::sun::star::uno::Any& Next) throw ( ::com::sun::star::sdbc::SQLException )
+void throwInvalidIndexException(const css::uno::Reference< css::uno::XInterface >& Context,
+ const css::uno::Any& Next) throw ( css::sdbc::SQLException )
{
::connectivity::SharedResources aResources;
throw SQLException(
@@ -399,8 +399,8 @@ void throwFunctionNotSupportedRuntimeException(const OUString& _rFunctionName,
);
}
-void throwGenericSQLException(const OUString& _rMsg, const ::com::sun::star::uno::Reference< ::com::sun::star::uno::XInterface >& _rxSource)
- throw (::com::sun::star::sdbc::SQLException)
+void throwGenericSQLException(const OUString& _rMsg, const css::uno::Reference< css::uno::XInterface >& _rxSource)
+ throw (css::sdbc::SQLException)
{
throwGenericSQLException(_rMsg, _rxSource, Any());
}
diff --git a/connectivity/source/commontools/dbtools.cxx b/connectivity/source/commontools/dbtools.cxx
index 69c1524ab555..45e0e36659a2 100644
--- a/connectivity/source/commontools/dbtools.cxx
+++ b/connectivity/source/commontools/dbtools.cxx
@@ -1640,7 +1640,7 @@ namespace
public:
OParameterWrapper(const ::std::vector<bool, std::allocator<bool> >& _aSet,const Reference<XIndexAccess>& _xSource) : m_aSet(_aSet),m_xSource(_xSource){}
private:
- // ::com::sun::star::container::XElementAccess
+ // css::container::XElementAccess
virtual Type SAL_CALL getElementType() throw(RuntimeException, std::exception) override
{
return m_xSource->getElementType();
@@ -1651,7 +1651,7 @@ namespace
return m_xSource->hasElements();
return ::std::count(m_aSet.begin(),m_aSet.end(),false) != 0;
}
- // ::com::sun::star::container::XIndexAccess
+ // css::container::XIndexAccess
virtual sal_Int32 SAL_CALL getCount( ) throw(RuntimeException, std::exception) override
{
if ( m_aSet.empty() )
@@ -1822,7 +1822,7 @@ void setObjectWithInfo(const Reference<XParameters>& _xParams,
_xParams->setClob(parameterIndex,xClob);
else
{
- Reference< ::com::sun::star::io::XInputStream > xStream;
+ Reference< css::io::XInputStream > xStream;
if(x >>= xStream)
_xParams->setCharacterStream(parameterIndex,xStream,xStream->available());
}
@@ -1873,7 +1873,7 @@ void setObjectWithInfo(const Reference<XParameters>& _xParams,
_xParams->setClob(parameterIndex,xClob);
else
{
- Reference< ::com::sun::star::io::XInputStream > xBinStream;
+ Reference< css::io::XInputStream > xBinStream;
if(x >>= xBinStream)
_xParams->setBinaryStream(parameterIndex,xBinStream,xBinStream->available());
}
@@ -1966,7 +1966,7 @@ namespace connectivity
void release(oslInterlockedCount& _refCount,
::cppu::OBroadcastHelper& rBHelper,
Reference< XInterface >& _xInterface,
- ::com::sun::star::lang::XComponent* _pObject)
+ css::lang::XComponent* _pObject)
{
if (osl_atomic_decrement( &_refCount ) == 0)
{
diff --git a/connectivity/source/commontools/parameters.cxx b/connectivity/source/commontools/parameters.cxx
index 73619e837db8..32c2cc0a520a 100644
--- a/connectivity/source/commontools/parameters.cxx
+++ b/connectivity/source/commontools/parameters.cxx
@@ -1018,73 +1018,73 @@ namespace dbtools
}
- void ParameterManager::setBytes( sal_Int32 _nIndex, const ::com::sun::star::uno::Sequence< sal_Int8 >& x )
+ void ParameterManager::setBytes( sal_Int32 _nIndex, const css::uno::Sequence< sal_Int8 >& x )
{
VISIT_PARAMETER( setBytes( _nIndex, x ) );
}
- void ParameterManager::setDate( sal_Int32 _nIndex, const ::com::sun::star::util::Date& x )
+ void ParameterManager::setDate( sal_Int32 _nIndex, const css::util::Date& x )
{
VISIT_PARAMETER( setDate( _nIndex, x ) );
}
- void ParameterManager::setTime( sal_Int32 _nIndex, const ::com::sun::star::util::Time& x )
+ void ParameterManager::setTime( sal_Int32 _nIndex, const css::util::Time& x )
{
VISIT_PARAMETER( setTime( _nIndex, x ) );
}
- void ParameterManager::setTimestamp( sal_Int32 _nIndex, const ::com::sun::star::util::DateTime& x )
+ void ParameterManager::setTimestamp( sal_Int32 _nIndex, const css::util::DateTime& x )
{
VISIT_PARAMETER( setTimestamp( _nIndex, x ) );
}
- void ParameterManager::setBinaryStream( sal_Int32 _nIndex, const ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream>& x, sal_Int32 length )
+ void ParameterManager::setBinaryStream( sal_Int32 _nIndex, const css::uno::Reference< css::io::XInputStream>& x, sal_Int32 length )
{
VISIT_PARAMETER( setBinaryStream( _nIndex, x, length ) );
}
- void ParameterManager::setCharacterStream( sal_Int32 _nIndex, const ::com::sun::star::uno::Reference< ::com::sun::star::io::XInputStream>& x, sal_Int32 length )
+ void ParameterManager::setCharacterStream( sal_Int32 _nIndex, const css::uno::Reference< css::io::XInputStream>& x, sal_Int32 length )
{
VISIT_PARAMETER( setCharacterStream( _nIndex, x, length ) );
}
- void ParameterManager::setObject( sal_Int32 _nIndex, const ::com::sun::star::uno::Any& x )
+ void ParameterManager::setObject( sal_Int32 _nIndex, const css::uno::Any& x )
{
VISIT_PARAMETER( setObject( _nIndex, x ) );
}
- void ParameterManager::setObjectWithInfo( sal_Int32 _nIndex, const ::com::sun::star::uno::Any& x, sal_Int32 targetSqlType, sal_Int32 scale )
+ void ParameterManager::setObjectWithInfo( sal_Int32 _nIndex, const css::uno::Any& x, sal_Int32 targetSqlType, sal_Int32 scale )
{
VISIT_PARAMETER( setObjectWithInfo( _nIndex, x, targetSqlType, scale ) );
}
- void ParameterManager::setRef( sal_Int32 _nIndex, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRef>& x )
+ void ParameterManager::setRef( sal_Int32 _nIndex, const css::uno::Reference< css::sdbc::XRef>& x )
{
VISIT_PARAMETER( setRef( _nIndex, x ) );
}
- void ParameterManager::setBlob( sal_Int32 _nIndex, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XBlob>& x )
+ void ParameterManager::setBlob( sal_Int32 _nIndex, const css::uno::Reference< css::sdbc::XBlob>& x )
{
VISIT_PARAMETER( setBlob( _nIndex, x ) );
}
- void ParameterManager::setClob( sal_Int32 _nIndex, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XClob>& x )
+ void ParameterManager::setClob( sal_Int32 _nIndex, const css::uno::Reference< css::sdbc::XClob>& x )
{
VISIT_PARAMETER( setClob( _nIndex, x ) );
}
- void ParameterManager::setArray( sal_Int32 _nIndex, const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XArray>& x )
+ void ParameterManager::setArray( sal_Int32 _nIndex, const css::uno::Reference< css::sdbc::XArray>& x )
{
VISIT_PARAMETER( setArray( _nIndex, x ) );
}
diff --git a/connectivity/source/commontools/FValue.cxx b/connectivity/source/commontools/FValue.cxx
index 9e86bf2e77da..62861bf945c9 100644
--- a/connectivity/source/commontools/FValue.cxx
+++ b/connectivity/source/commontools/FValue.cxx
@@ -1844,7 +1844,7 @@ Sequence<sal_Int8> ORowSetValue::getSequence() const
do
{
- ::com::sun::star::uno::Sequence< sal_Int8 > aReadSeq;
+ css::uno::Sequence< sal_Int8 > aReadSeq;
nRead = xStream->readSomeBytes( aReadSeq, nBytesToRead );
@@ -1885,9 +1885,9 @@ Sequence<sal_Int8> ORowSetValue::getSequence() const
}
-::com::sun::star::util::Date ORowSetValue::getDate() const
+css::util::Date ORowSetValue::getDate() const
{
- ::com::sun::star::util::Date aValue;
+ css::util::Date aValue;
if(!m_bNull)
{
switch(m_eTypeKind)
@@ -1906,11 +1906,11 @@ Sequence<sal_Int8> ORowSetValue::getSequence() const
break;
case DataType::DATE:
- aValue = *static_cast< ::com::sun::star::util::Date*>(m_aValue.m_pValue);
+ aValue = *static_cast< css::util::Date*>(m_aValue.m_pValue);
break;
case DataType::TIMESTAMP:
{
- ::com::sun::star::util::DateTime* pDateTime = static_cast< ::com::sun::star::util::DateTime*>(m_aValue.m_pValue);
+ css::util::DateTime* pDateTime = static_cast< css::util::DateTime*>(m_aValue.m_pValue);
aValue.Day = pDateTime->Day;
aValue.Month = pDateTime->Month;
aValue.Year = pDateTime->Year;
@@ -1943,9 +1943,9 @@ Sequence<sal_Int8> ORowSetValue::getSequence() const
return aValue;
}
-::com::sun::star::util::Time ORowSetValue::getTime() const
+css::util::Time ORowSetValue::getTime() const
{
- ::com::sun::star::util::Time aValue;
+ css::util::Time aValue;
if(!m_bNull)
{
switch(m_eTypeKind)
@@ -1966,7 +1966,7 @@ Sequence<sal_Int8> ORowSetValue::getSequence() const
break;
case DataType::TIMESTAMP:
{
- ::com::sun::star::util::DateTime* pDateTime = static_cast< ::com::sun::star::util::DateTime*>(m_aValue.m_pValue);
+ css::util::DateTime* pDateTime = static_cast< css::util::DateTime*>(m_aValue.m_pValue);
aValue.NanoSeconds = pDateTime->NanoSeconds;
aValue.Seconds = pDateTime->Seconds;
aValue.Minutes = pDateTime->Minutes;
@@ -1974,7 +1974,7 @@ Sequence<sal_Int8> ORowSetValue::getSequence() const
}
break;
case DataType::TIME:
- aValue = *static_cast< ::com::sun::star::util::Time*>(m_aValue.m_pValue);
+ aValue = *static_cast< css::util::Time*>(m_aValue.m_pValue);
break;
default:
{
@@ -1987,9 +1987,9 @@ Sequence<sal_Int8> ORowSetValue::getSequence() const
return aValue;
}
-::com::sun::star::util::DateTime ORowSetValue::getDateTime() const
+css::util::DateTime ORowSetValue::getDateTime() const
{
- ::com::sun::star::util::DateTime aValue;
+ css::util::DateTime aValue;
if(!m_bNull)
{
switch(m_eTypeKind)
@@ -2010,7 +2010,7 @@ Sequence<sal_Int8> ORowSetValue::getSequence() const
break;
case DataType::DATE:
{
- ::com::sun::star::util::Date* pDate = static_cast< ::com::sun::star::util::Date*>(m_aValue.m_pValue);
+ css::util::Date* pDate = static_cast< css::util::Date*>(m_aValue.m_pValue);
aValue.Day = pDate->Day;
aValue.Month = pDate->Month;
aValue.Year = pDate->Year;
@@ -2018,7 +2018,7 @@ Sequence<sal_Int8> ORowSetValue::getSequence() const
break;
case DataType::TIME:
{
- ::com::sun::star::util::Time* pTime = static_cast< ::com::sun::star::util::Time*>(m_aValue.m_pValue);
+ css::util::Time* pTime = static_cast< css::util::Time*>(m_aValue.m_pValue);
aValue.NanoSeconds = pTime->NanoSeconds;
aValue.Seconds = pTime->Seconds;
aValue.Minutes = pTime->Minutes;
@@ -2026,7 +2026,7 @@ Sequence<sal_Int8> ORowSetValue::getSequence() const
}
break;
case DataType::TIMESTAMP:
- aValue = *static_cast< ::com::sun::star::util::DateTime*>(m_aValue.m_pValue);
+ aValue = *static_cast< css::util::DateTime*>(m_aValue.m_pValue);
break;
default:
{
@@ -2197,7 +2197,7 @@ void ORowSetValue::fill( sal_Int32 _nPos, sal_Int32 _nType, bool _bNullable, co
void ORowSetValue::fill(sal_Int32 _nPos,
sal_Int32 _nType,
- const ::com::sun::star::uno::Reference< ::com::sun::star::sdbc::XRow>& _xRow)
+ const css::uno::Reference< css::sdbc::XRow>& _xRow)
{
fill(_nPos,_nType,true,_xRow);
}
@@ -2220,7 +2220,7 @@ void ORowSetValue::impl_fill( const sal_Int32 _nType, bool _bNullable, const det
(*this) = _rValueSource.getLong();
else
// TODO: this is rather horrible performance-wise
// but fixing it needs extending the ::com::sun::star::sdbc::XRow API
// to have a getULong(), and needs updating all drivers :-|
// When doing that, add getUByte, getUShort, getUInt for symmetry/completeness
(*this) = _rValueSource.getString().toUInt64();
@@ -2269,11 +2269,11 @@ void ORowSetValue::impl_fill( const sal_Int32 _nType, bool _bNullable, const det
(*this) = _rValueSource.getLong();
break;
case DataType::CLOB:
- (*this) = ::com::sun::star::uno::makeAny(_rValueSource.getClob());
+ (*this) = css::uno::makeAny(_rValueSource.getClob());
setTypeKind(DataType::CLOB);
break;
case DataType::BLOB:
- (*this) = ::com::sun::star::uno::makeAny(_rValueSource.getBlob());
+ (*this) = css::uno::makeAny(_rValueSource.getBlob());
setTypeKind(DataType::BLOB);
break;
case DataType::OTHER:
@@ -2402,9 +2402,9 @@ void ORowSetValue::fill(const Any& _rValue)
case TypeClass_STRUCT:
{
- ::com::sun::star::util::Date aDate;
- ::com::sun::star::util::Time aTime;
- ::com::sun::star::util::DateTime aDateTime;
+ css::util::Date aDate;
+ css::util::Time aTime;
+ css::util::DateTime aDateTime;
if ( _rValue >>= aDate )
{
(*this) = aDate;
@@ -2220,7 +2220,7 @@ void ORowSetValue::impl_fill( const sal_Int32 _nType, bool _bNullable, const det
else
// TODO: this is rather horrible performance-wise
- // but fixing it needs extending the ::com::sun::star::sdbc::XRow API
+ // but fixing it needs extending the css::sdbc::XRow API
// to have a getULong(), and needs updating all drivers :-|
// When doing that, add getUByte, getUShort, getUInt for symmetry/completeness